Contact Us - Wilsons Leather
Description: Contact Us
Keywords: Contact Us

Bizrate

### Extra 50% Off Sitewide! Use code GIFTS at Checkout + Free Shipping Over $50 *Continental US

## Contact Us

First Name
Last Name
* Email
* Concerns
* Message:

### Wilsons Leather

Phone:
1-866-305-4704
Email:
customercare@wilsonsleather.com
Mail:
Wilsons Leather
PO Box 8868
Pueblo, CO 81008

### Customer Service

- Contact Us
- Ordering and Payment
- Returns and Exchanges
- Shipping Information
- FAQ
- Privacy and Security
- Terms of Use
- Size Charts